@@ -137,7 +137,7 @@ class AlchemyJsonApiViewBuilder:
                     self._skip_plugins.remove(item)
 
         return self
-    
+
     @property
     def is_admin(self) -> bool:
         return self._is_admin
@@ -208,6 +208,11 @@ class AlchemyJsonApiViewBuilder:
         self.__warn_if_method_not_available(json_api_spec_http_methods.HTTP_GET)
         return self
 
+    def add_field(self, name: str) -> 'AlchemyJsonApiViewBuilder':
+        if name not in self._fields:
+            self._fields.append(name)
+        return self
+
     def add_relation(self, field: str,
                      model: Type,
                      resource_name: str,
@@ -234,10 +239,15 @@ class AlchemyJsonApiViewBuilder:
                  url_resource_name: Optional[str] = None,
                  urls_prefix: Optional[str] = None,
                  ignore_serializer: Optional[bool] = False) -> List[url]:
+        SchemaType = None
         if ignore_serializer:
-            SchemaType = list(filter(lambda item: item['api_version'] == self._api_version,
-                                     _TYPE_TO_SCHEMA[self._model]))[0]['serializer']
-        else:
+            SchemaType = list(
+                filter(lambda item: item['api_version'] == self._api_version and item['is_admin'] == self.is_admin,
+                       _TYPE_TO_SCHEMA[self._model]))
+            if SchemaType:
+                SchemaType = SchemaType[0]['serializer']
+
+        if not SchemaType:
             SchemaType = auto_construct_schema(self._model,
                                                resource_name=self._resource_name,
                                                api_version=self._api_version,
@@ -279,20 +289,23 @@ class AlchemyJsonApiViewBuilder:
                                                                          [getattr(item, local_column.name) for item in
                                                                           objects]
                                                                      )).all()
-                    schema = list(filter(lambda item: item['api_version'] == self._api_version,
-                                _TYPE_TO_SCHEMA[target_model]))[0]
+                    relevant_relation = next(
+                        (relation for relation in self._relations if relation.field_name == include), None)
+                    schema = list(filter(lambda item: item['api_version'] == relevant_relation.api_version and item[
+                        'is_admin'] == self.is_admin,
+                                         _TYPE_TO_SCHEMA[target_model]))[0]
                     target_many = schema['serializer'](many=True)
                     #  Serialize all the included objects to JSON:API
                     include_result = target_many.json_api_dump(to_include, schema['resource_name'],
                                                                with_data=False)
                     rendered_includes.extend(include_result)
                 else:
-                    raise Exception(f'Include {include} not supported on type {self._resource_name}')
+                    LOGGER.error(f'Include {include} not supported on type {self._resource_name}')
             return rendered_includes
 
         permitted_objects = self._permitted_objects or default_permitted_objects
 
-        def object_get(request, identifier, *args, **kwargs) -> Tuple[Dict, int]:
+        def object_get(request, identifier, includes, *args, **kwargs) -> Tuple[Dict, int]:
             permitted_query = permitted_objects(request,
                                                 self._base_query() if self._base_query is not None else self._model.objects.query())
 
@@ -309,12 +322,13 @@ class AlchemyJsonApiViewBuilder:
             if self._after_get_callback:
                 obj = self._after_get_callback(request, obj)
 
+            rendered_includes = render_includes(includes, [obj])
             result = schema.json_api_dump(obj, self._resource_name)
 
             if self._before_get_response:
                 result = self._before_get_response(request, obj, result)
 
-            return result, HTTP_200_OK
+            return result, rendered_includes, HTTP_200_OK
 
         def object_list(request, page, filters=None, includes=None, *args, **kwargs) -> Tuple[List, List, int, int]:
             permitted_query = permitted_objects(request,
